@@ -8,7 +8,7 @@ package Tickit::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.64';
+our $VERSION = '0.66';
 
 use Carp;
 
@@ -89,10 +89,6 @@ package
    Tickit::Event::Key;
 our @ISA = qw( Tickit::Event );
 
-use overload '%{}' => sub {
-   Carp::croak "HASH access to Tickit::Event::Key is deprecated";
-};
-
 =head1 Tickit::Event::Key
 
 =head2 type
@@ -113,10 +109,6 @@ package
    Tickit::Event::Mouse;
 our @ISA = qw( Tickit::Event );
 
-use overload '%{}' => sub {
-   Carp::croak "HASH access to Tickit::Event::Mouse is deprecated";
-};
-
 =head1 Tickit::Event::Mouse
 
 =head2 type
@@ -144,10 +136,6 @@ package
    Tickit::Event::Resize;
 our @ISA = qw( Tickit::Event );
 
-use overload '%{}' => sub {
-   Carp::croak "HASH access to Tickit::Event::Resize is deprecated";
-};
-
 =head1 Tickit::Event::Resize
 
 =head2 lines
