@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2018 -- leonerd@leonerd.org.uk
 
 package Tickit::Term;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.64';
+our $VERSION = '0.66';
 
 use Carp;
 
@@ -113,6 +113,15 @@ sub new
    return $self;
 }
 
+=head2 open_stdio
+
+   $term = Tickit::Term->open_stdio
+
+Convenient shortcut for obtaining a L<Tickit::Term> instance bound to the
+STDIN and STDOUT streams of the process.
+
+=cut
+
 =head1 METHODS
 
 =cut
@@ -174,6 +183,33 @@ seconds.
 
 =cut
 
+=head2 pause
+
+   $term->pause
+
+Suspends operation of the terminal by resetting it to its default state.
+
+=cut
+
+=head2 resume
+
+   $term->resume
+
+Resumes operation of the terminal after a L</pause>.
+
+Typically these two methods are used together, either side of a blocking wait
+around a C<SIGSTOP>.
+
+   sub suspend
+   {
+      $term->pause;
+      kill STOP => $$;
+      $term->resume;
+      $rootwin->expose;
+   }
+
+=cut
+
 =head2 flush
 
    $term->flush
@@ -202,7 +238,7 @@ L<Tickit::Event>.
 
    $id = $term->bind_event( $ev, $flags, $code, $data )
 
-The C<$code> argument may optionally be preceeded by an integer of flag
+The C<$code> argument may optionally be preceded by an integer of flag
 values. This should be zero to apply default semantics, or a bitmask of one or
 more of the following constants:
 
@@ -231,11 +267,6 @@ sub bind_event
    $self->_bind_event( $ev, $flags, $code, $data );
 }
 
-sub bind_event_default
-{
-   croak "\term->bind_event_default is deprecated; use ->bind_event";
-}
-
 =head2 refresh_size
 
    $term->refresh_size
